@@ -34,7 +34,7 @@
 #include "vstr.h"
 #include "config.h"
 
-static char gp_title[] = "dvdspanky 1.0.7 - (c) 2007 Jeffrey Grembecki\n\n";
+static char gp_title[] = "dvdspanky 1.0.8 - (c) 2007 Jeffrey Grembecki\n\n";
 static char gp_licence[] =
 "This program is free software; you can redistribute it and/or modify\n"
 "it under the terms of the GNU General Public License as published by\n"
@@ -1266,15 +1266,16 @@ int main(int argc, char **argv)
 		int p_vector[10];
 		int found;
 
-		p_regex = pcre_compile("^.*?([^/.]+)(?:\\.|)[^/.]*$", 0, &p_error, &erroffset, NULL);
+		p_regex = pcre_compile("^(?:.*[/]|)(.*?)(?:[.][^.]+|)$", 0, &p_error, &erroffset, NULL);
+
 		if(!p_regex)
 		{
-			printerror("failed to compile filename regex");
+			printerror("failed to compile filename regex - %s", p_error);
 			exit(1);
 		}
 		found = pcre_exec(p_regex, NULL, invid.p_filename, strlen(invid.p_filename), 0, 0,
 			p_vector, sizeof(p_vector) / sizeof(int));
-		if(found > 0)
+		if(found > 1)
 		{
 			strncpy(outvid.p_filename, &(invid.p_filename[p_vector[2]]), p_vector[3] - p_vector[2]);
 			outvid.p_filename[p_vector[3] - p_vector[2]] = 0;
